checkCountsWholeNumbers: Check that the count data contain only integer counts
Description
Check that the count data contain only integer counts
Usage
checkCountsWholeNumbers(input.matrix)
Arguments
aggregated.samples
the count data from aggreaged samples input to DESeq
Value
if non-integer counts are found, an error is returned