Evaluate how many clusters are global
getPercentGlobalClusters(
p2list,
pjc,
pc.samples.cutoff = 0.9,
min.cell.count.per.sample = 10
)list of pagoda2 object on which clustering was generated
the result of joint clustering
numeric The percent of the number of the total samples that a cluster has to span to be considered global (default=0.9)
numeric The minimum number of cells of cluster in sample to be considered as represented in that sample (default=10)
percent of clusters that are global given the above criteria