Learn R Programming

conos (version 1.4.3)

namedLevels: Get a vector with the levels of a factor named with their own name. Useful for lapply loops over factor levels

Description

Get a vector with the levels of a factor named with their own name. Useful for lapply loops over factor levels

Usage

namedLevels(f)

Arguments

f

a factor

Value

named character vector of factor levels