Plot a heatmap of differential genes
plotDEheatmap(
con,
groups,
de = NULL,
min.auc = NULL,
min.specificity = NULL,
min.precision = NULL,
n.genes.per.cluster = 10,
additional.genes = NULL,
exclude.genes = NULL,
labeled.gene.subset = NULL,
expression.quantile = 0.99,
pal = colorRampPalette(c("dodgerblue1", "grey95", "indianred1"))(1024),
ordering = "-AUC",
column.metadata = NULL,
show.gene.clusters = TRUE,
remove.duplicates = TRUE,
column.metadata.colors = NULL,
show.cluster.legend = TRUE,
show_heatmap_legend = FALSE,
border = TRUE,
return.details = FALSE,
row.label.font.size = 10,
order.clusters = FALSE,
split = FALSE,
split.gap = 0,
cell.order = NULL,
averaging.window = 0,
max.cells = Inf,
...
)conos (or p2) object
groups in which the DE genes were determined (so that the cells can be ordered correctly)
differential expression result (list of data frames) (default=NULL)
optional minimum AUC threshold (default=NULL)
optional minimum specificity threshold (default=NULL)
optional minimum precision threshold (default=NULL)
numeric Number of genes to show for each cluster (default=10)
optional additional genes to include (the genes will be assigned to the closest cluster) (default=NULL)
an optional list of genes to exclude from the heatmap (default=NULL)
a subset of gene names to show (instead of all genes) (default=NULL). Can be a vector of gene names, or a number of top genes (in each cluster) to show the names for.
numeric Expression quantile to show (default=0.99)
palette to use for the main heatmap (default=colorRampPalette(c('dodgerblue1','grey95','indianred1'))(1024))
order by which the top DE genes (to be shown) are determined (default "-AUC")
additional column metadata, passed either as a data.frame with rows named as cells, or as a list of named cell factors (default=NULL).
whether to show gene cluster color codes
remove duplicated genes (leaving them in just one of the clusters)
a list of color specifications for additional column metadata, specified according to the HeatmapMetadata format. Use "clusters" slot to specify cluster colors.
boolean Whether to show the cluster legend (default=TRUE)
boolean Whether to show the expression heatmap legend (default=FALSE)
boolean Whether to show borders around the heatmap and annotations (default=TRUE)
boolean If TRUE will return a list containing the heatmap (ha), but also raw matrix (x), expression list (expl) and other info to produce the heatmap on your own (default=FALSE).
numeric Font size for the row labels (default=10)
boolean Whether to re-order the clusters according to the similarity of the expression patterns (of the genes being shown) (default=FALSE)
boolean Whether to use arguments "row_split" and "column_split" in ComplexHeatmap::Heatmap() (default=FALSE). These arguments are categorical vectors used to split the rows/columns in the heatmap.
numeric Value of millimeters "mm" to use for 'row_gap' and 'column_gap' (default=0). If split is FALSE, this argument is ignored.
explicitly supply cell order (default=NULL)
numeric Optional window averaging between neighboring cells within each group (turned off by default) - useful when very large number of cells shown (requires zoo package) (default=0)
numeric Maximum cells to include in any given group (default: Inf)
extra parameters are passed to ComplexHeatmap::Heatmap() call
ComplexHeatmap::Heatmap object (see return.details param for other output)